@@ -1,4 +1,5 @@
-from terminusgps.wialon import constants, flags
+from typing import Type
+from terminusgps.wialon import flags
 from terminusgps.wialon.items.base import WialonBase
 
 
@@ -31,7 +32,7 @@ class WialonUnitGroup(WialonBase):
         )
         return response.get("item", {}).get("id")
 
-    def _update_items(self, new_items: list[str]) -> None:
+    def set_items(self, new_items: list[str]) -> None:
         """
         Sets this group's members to a list of Wialon unit ids.
 
@@ -47,7 +48,7 @@ class WialonUnitGroup(WialonBase):
             **{"itemId": self.id, "units": new_items}
         )
 
-    def is_member(self, item: WialonBase) -> bool:
+    def is_member(self, item: Type[WialonBase]) -> bool:
         """
         Determines whether or not ``item`` is a member of the group.
 
@@ -60,43 +61,9 @@ class WialonUnitGroup(WialonBase):
         """
         return True if str(item.id) in self.items else False
 
-    def grant_access(
-        self, item: WialonBase, access_mask: int = constants.ACCESSMASK_UNIT_BASIC
-    ) -> None:
+    def add_item(self, item: Type[WialonBase]) -> None:
         """
-        Grants ``item`` access to the group, if it didn't already have access.
-
-        :param item: A Wialon object.
-        :type item: :py:obj:`~terminusgps.wialon.items.base.WialonBase`
-        :param access_mask: A Wialon access mask.
-        :type access_mask: :py:obj:`int`
-        :raises WialonError: If something goes wrong with Wialon.
-        :returns: Nothing.
-        :rtype: :py:obj:`None`
-
-        """
-        self.session.wialon_api.user_update_item_access(
-            **{"userId": item.id, "itemId": self.id, "accessMask": access_mask}
-        )
-
-    def revoke_access(self, item: WialonBase) -> None:
-        """
-        Revokes ``item``'s access from the group, if it had access.
-
-        :param item: A Wialon object.
-        :type item: :py:obj:`~terminusgps.wialon.items.base.WialonBase`
-        :raises WialonError: If something goes wrong with Wialon.
-        :returns: Nothing.
-        :rtype: :py:obj:`None`
-
-        """
-        self.session.wialon_api.user_update_item_access(
-            **{"userId": item.id, "itemId": self.id, "accessMask": 0}
-        )
-
-    def add_item(self, item: WialonBase) -> None:
-        """
-        Adds a Wialon unit to the group.
+        Adds a Wialon item to the group.
 
         :param item: A Wialon object.
         :type item: :py:obj:`~terminusgps.wialon.items.base.WialonBase`
@@ -106,9 +73,9 @@ class WialonUnitGroup(WialonBase):
 
         """
         new_items: list[str] = self.items.copy() + [str(item.id)]
-        self._update_items(new_items)
+        self.set_items(new_items)
 
-    def rm_item(self, item: WialonBase) -> None:
+    def rm_item(self, item: Type[WialonBase]) -> None:
         """
         Removes a Wialon unit from the group, if it's a member of the group.
 
@@ -123,7 +90,7 @@ class WialonUnitGroup(WialonBase):
         assert self.is_member(item), f"Cannot remove {item}, it's not in the group"
         new_items: list[str] = self.items.copy()
         new_items.remove(str(item.id))
-        self._update_items(new_items)
+        self.set_items(new_items)
 
     @property
     def items(self) -> list[str]:
@@ -149,9 +116,4 @@ class WialonUnitGroup(WialonBase):
                 "to": 0,
             }
         )
-        items = [
-            unit_id
-            for unit_id in response.get("items")[0].get("u", [])
-            if response.get("items")
-        ]
-        return items
+        return [unit_id for unit_id in response.get("items")[0].get("u", [])]
